@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -67,46 +67,24 @@ QCoreApplication *createClientApplication(int &argc, char **argv, const QStringL
              ) )
     {
         QGuiApplication::setDesktopSettingsAware(false);
-        const auto app = createPlatformNativeInterface()
+        const auto app = platformNativeInterface()
                 ->createClipboardProviderApplication(argc, argv);
         setCurrentThreadName(arguments[0]);
         return app;
     }
 
-    const auto app = createPlatformNativeInterface()->createClientApplication(argc, argv);
+    const auto app = platformNativeInterface()->createClientApplication(argc, argv);
     setCurrentThreadName("Client");
     return app;
 }
 
 } // namespace
 
-void InputReader::readInput()
-{
-    QFile in;
-    in.open(stdin, QIODevice::ReadOnly);
-
-    QByteArray input = in.readAll();
-    emit inputRead(input);
-}
-
 ClipboardClient::ClipboardClient(int &argc, char **argv, const QStringList &arguments, const QString &sessionName)
     : App(createClientApplication(argc, argv, arguments), sessionName)
-    , m_inputReaderThread(nullptr)
 {
     restoreSettings();
 
-    const auto serverName = clipboardServerName();
-    m_socket = new ClientSocket(serverName, this);
-
-    connect( m_socket, &ClientSocket::messageReceived,
-             this, &ClipboardClient::onMessageReceived );
-    connect( m_socket, &ClientSocket::disconnected,
-             this, &ClipboardClient::onDisconnected );
-    connect( m_socket, &ClientSocket::connectionFailed,
-             this, &ClipboardClient::onConnectionFailed );
-
-    m_socket->start();
-
     // Start script after QCoreApplication::exec().
     auto timer = new QTimer(this);
     timer->setSingleShot(true);
@@ -130,14 +108,7 @@ void ClipboardClient::onMessageReceived(const QByteArray &data, int messageCode)
     }
 
     case CommandStop: {
-        emit stopEventLoops();
-
-        // Stop any event loops started later.
-        auto timer = new QTimer(this);
-        timer->setInterval(250);
-        connect(timer, &QTimer::timeout, this, &ClipboardClient::stopEventLoops);
-        connect(timer, &QTimer::timeout, timer, &QTimer::deleteLater);
-        timer->start();
+        exit(0);
         break;
     }
 
@@ -154,8 +125,6 @@ void ClipboardClient::onDisconnected()
 
     log( tr("Connection lost!"), LogError );
 
-    abortInputReader();
-
     exit(1);
 }
 
@@ -165,106 +134,52 @@ void ClipboardClient::onConnectionFailed()
     exit(1);
 }
 
-void ClipboardClient::setInput(const QByteArray &input)
-{
-    m_input = input;
-    sendInput();
-    abortInputReader();
-}
-
-void ClipboardClient::sendInput()
-{
-    if ( !wasClosed() )
-        emit inputReceived(m_input);
-}
-
-void ClipboardClient::exit(int exitCode)
-{
-    abortInputReader();
-    App::exit(exitCode);
-}
-
-void ClipboardClient::startInputReader()
-{
-    if ( wasClosed() || m_inputReaderThread )
-        return;
-
-    if ( isInputReaderFinished() ) {
-        sendInput();
-        return;
-    }
-
-    auto reader = new InputReader;
-    m_inputReaderThread = new QThread(this);
-    reader->moveToThread(m_inputReaderThread);
-    connect( m_inputReaderThread, &QThread::started, reader, &InputReader::readInput );
-    connect( m_inputReaderThread, &QThread::finished, reader, &InputReader::deleteLater );
-    connect( reader, &InputReader::inputRead, this, &ClipboardClient::setInput );
-    m_inputReaderThread->start();
-}
-
-void ClipboardClient::abortInputReader()
-{
-    if (m_inputReaderThread) {
-        m_inputReaderThread->exit();
-        if (!m_inputReaderThread->wait(2000)) {
-            m_inputReaderThread->terminate();
-            m_inputReaderThread->wait(2000);
-        }
-    }
-}
-
-bool ClipboardClient::isInputReaderFinished() const
-{
-    return m_inputReaderThread && m_inputReaderThread->isFinished();
-}
-
 void ClipboardClient::start(const QStringList &arguments)
 {
     QScriptEngine engine;
     ScriptableProxy scriptableProxy(nullptr, nullptr);
     Scriptable scriptable(&engine, &scriptableProxy);
 
-    connect( &scriptable, &Scriptable::readInput,
-             this, &ClipboardClient::startInputReader );
+    const auto serverName = clipboardServerName();
+    ClientSocket socket(serverName);
+
+    connect( &socket, &ClientSocket::messageReceived,
+             this, &ClipboardClient::onMessageReceived );
+    connect( &socket, &ClientSocket::disconnected,
+             this, &ClipboardClient::onDisconnected );
+    connect( &socket, &ClientSocket::connectionFailed,
+             this, &ClipboardClient::onConnectionFailed );
+
     connect( &scriptableProxy, &ScriptableProxy::sendMessage,
-             m_socket, &ClientSocket::sendMessage );
+             &socket, &ClientSocket::sendMessage );
 
-    connect( this, &ClipboardClient::inputReceived,
-             &scriptable, &Scriptable::setInput );
     connect( this, &ClipboardClient::functionCallResultReceived,
              &scriptableProxy, &ScriptableProxy::setFunctionCallReturnValue );
     connect( this, &ClipboardClient::inputDialogFinished,
              &scriptableProxy, &ScriptableProxy::setInputDialogResult );
 
-    connect( m_socket, &ClientSocket::disconnected,
+    connect( &socket, &ClientSocket::disconnected,
              &scriptable, &Scriptable::abort );
-    connect( m_socket, &ClientSocket::disconnected,
+    connect( &socket, &ClientSocket::disconnected,
              &scriptableProxy, &ScriptableProxy::clientDisconnected );
 
-    connect( this, &ClipboardClient::stopEventLoops,
-             &scriptable, &Scriptable::stopEventLoops );
-    connect( qApp, &QCoreApplication::aboutToQuit,
-             &scriptable, &Scriptable::stopEventLoops );
-
-    connect( &scriptable, &Scriptable::finished,
-             this, &ClipboardClient::scriptableFinished );
     connect( &scriptable, &Scriptable::finished,
              &scriptableProxy, &ScriptableProxy::clientDisconnected );
 
-    bool hasData;
+    bool hasActionId;
 #if QT_VERSION < QT_VERSION_CHECK(5,5,0)
-    auto actionId = qgetenv("COPYQ_ACTION_ID").toInt(&hasData);
+    auto actionId = qgetenv("COPYQ_ACTION_ID").toInt(&hasActionId);
 #else
-    auto actionId = qEnvironmentVariableIntValue("COPYQ_ACTION_ID", &hasData);
+    auto actionId = qEnvironmentVariableIntValue("COPYQ_ACTION_ID", &hasActionId);
 #endif
-    if (!hasData)
-        actionId = -1;
-    scriptable.setActionId(actionId);
-
     const auto actionName = getTextData( qgetenv("COPYQ_ACTION_NAME") );
-    scriptable.setActionName(actionName);
 
-    const int exitCode = scriptable.executeArguments(arguments);
-    exit(exitCode);
+    if ( socket.start() ) {
+        if (hasActionId)
+            scriptable.setActionId(actionId);
+        scriptable.setActionName(actionName);
+
+        const int exitCode = scriptable.executeArguments(arguments);
+        exit(exitCode);
+    }
 }
