@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -33,7 +33,7 @@ class QAction;
  * Execute external program and emits signals
  * to create or change items from the program's stdout.
  */
-class Action : public QObject
+class Action final : public QObject
 {
     Q_OBJECT
 public:
@@ -78,7 +78,7 @@ public:
 
     bool waitForStarted(int msecs);
 
-    bool waitForFinished(int msecs);
+    bool waitForFinished(int msecs = -1);
 
     bool isRunning() const;
 
