@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -136,6 +136,9 @@ void setGeometryOptionValue(const QString &optionName, const QVariant &value)
 
 void restoreWindowGeometry(QWidget *w, bool openOnCurrentScreen)
 {
+    if ( isGeometryGuardBlockedUntilHidden(w) )
+        return;
+
     const QString optionName = geometryOptionName(*w, GeometryAction::Restore, openOnCurrentScreen);
     const QString tag = resolutionTag(*w, GeometryAction::Restore, openOnCurrentScreen);
     QByteArray geometry = geometryOptionValue(optionName + tag).toByteArray();
