@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -46,7 +46,7 @@
  *   - copies settings from copy to real application settings and flushes it,
  *   - deletes special file.
  */
-class Settings
+class Settings final
 {
 public:
     static bool canModifySettings;
