@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -53,7 +53,7 @@ QString themePrefix()
 #ifdef COPYQ_THEME_PREFIX
     return COPYQ_THEME_PREFIX;
 #else
-    return createPlatformNativeInterface()->themePrefix();
+    return platformNativeInterface()->themePrefix();
 #endif
 }
 
