@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -31,10 +31,8 @@ class QSettings;
 
 struct Command;
 
-class ConfigTabShortcuts : public QWidget
+class ConfigTabShortcuts final : public QWidget
 {
-    Q_OBJECT
-
 public:
     explicit ConfigTabShortcuts(QWidget *parent = nullptr);
 
@@ -47,9 +45,6 @@ public:
 
     void addCommands(const QVector<Command> &commands);
 
-signals:
-    void commandsSaved();
-
 private:
     Ui::ConfigTabShortcuts *ui;
 };
