@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -362,11 +362,14 @@ public:
         return taggedIcon(&pixmap);
     }
 
-    QList<QSize> availableSizes(QIcon::Mode mode, QIcon::State state) const override
+    QList<QSize> availableSizes(QIcon::Mode, QIcon::State) const override
     {
-        auto sizes = QIconEngine::availableSizes(mode, state);
-        if ( !sizes.isEmpty() )
-            sizes.append( sizes.last() * 2 );
+        static const auto sizes = QList<QSize>()
+                << QSize(32, 32)
+                << QSize(48, 48)
+                << QSize(64, 64)
+                << QSize(96, 96)
+                << QSize(128, 128);
         return sizes;
     }
 
@@ -419,7 +422,7 @@ private:
     ushort m_iconId;
 };
 
-class ImageIconEngine : public FontIconEngine
+class ImageIconEngine final : public FontIconEngine
 {
 public:
     ImageIconEngine(const QString &iconName, ushort fallbackIconId, const QString &tag, QColor tagColor)
@@ -490,7 +493,7 @@ private:
     QString m_iconName;
 };
 
-class AppIconEngine : public BaseIconEngine
+class AppIconEngine final : public BaseIconEngine
 {
 public:
     AppIconEngine(AppIconType iconType)
@@ -525,7 +528,7 @@ private:
     AppIconType m_iconType;
 };
 
-class IconEngine
+class IconEngine final
 {
 public:
     static bool useSystemIcons;
