@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -46,7 +46,7 @@ class PersistentDisplayItem;
  * Before calling paint() for an index item on given index must be cached
  * using cache().
  */
-class ItemDelegate : public QItemDelegate
+class ItemDelegate final : public QItemDelegate
 {
     Q_OBJECT
 
@@ -88,9 +88,6 @@ class ItemDelegate : public QItemDelegate
         /** Set maximum size for all items. */
         void setItemSizes(QSize size, int idealWidth);
 
-        /** Use next/previous item loader available for @a index. */
-        bool otherItemLoader(const QModelIndex &index, bool next);
-
         /** Create internal item editor widget. */
         ItemEditorWidget *createCustomEditor(QWidget *parent, const QModelIndex &index,
                                              bool editNotes);
