@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -46,7 +46,7 @@ using ItemLoaderList = QVector<ItemLoaderPtr>;
  * Loads item plugins (loaders) and instantiates ItemWidget objects using appropriate
  * ItemLoaderInterface::create().
  */
-class ItemFactory : public QObject
+class ItemFactory final : public QObject
 {
     Q_OBJECT
 
@@ -73,11 +73,6 @@ public:
 
     ItemWidget *createSimpleItem(const QVariantMap &data, QWidget *parent, bool antialiasing);
 
-    /**
-     * Uses next/previous item loader to instantiate ItemWidget.
-     */
-    ItemWidget *otherItemLoader(const QVariantMap &data, ItemWidget *current, bool next, bool antialiasing);
-
     /**
      * Formats to save in history, union of enabled ItemLoaderInterface objects.
      */
@@ -143,6 +138,12 @@ public:
 
     void loadItemFactorySettings(QSettings *settings);
 
+    QObject *createExternalEditor(const QModelIndex &index, const QVariantMap &data, QWidget *parent) const;
+
+    QVariantMap data(const QModelIndex &index) const;
+
+    bool setData(const QVariantMap &data, const QModelIndex &index, QAbstractItemModel *model) const;
+
 signals:
     void error(const QString &errorString);
     void addCommands(const QVector<Command> &commands);
