@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -28,9 +28,10 @@
 #include <QDir>
 #include <QStringList>
 
-PlatformPtr createPlatformNativeInterface()
+PlatformNativeInterface *platformNativeInterface()
 {
-    return PlatformPtr(new DummyPlatform);
+    static DummyPlatform platform;
+    return &platform;
 }
 
 QCoreApplication *DummyPlatform::createConsoleApplication(int &argc, char **argv)
