@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -157,14 +157,6 @@ public:
     PlatformNativeInterface &operator=(const PlatformNativeInterface &) = delete;
 };
 
-/**
- * Shared pointer type for PlatformNativeInterface instance.
- */
-using PlatformPtr = std::shared_ptr<PlatformNativeInterface>;
-
-/**
- * Factory method to create PlatformNativeInterface instance.
- */
-PlatformPtr createPlatformNativeInterface();
+PlatformNativeInterface *platformNativeInterface();
 
 #endif // PLATFORMNATIVEINTERFACE_H
