@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -102,9 +102,10 @@ void maybePrintFileError(const QFile &file, const char *message)
 
 } // namespace
 
-PlatformPtr createPlatformNativeInterface()
+PlatformNativeInterface *platformNativeInterface()
 {
-    return PlatformPtr(new X11Platform);
+    static X11Platform platform;
+    return &platform;
 }
 
 X11Platform::~X11Platform() = default;
